================
Tutorials
================

The tutorial consists of a series of Google Colab notebooks. Static non-editable versions are also available. 


.. list-table::
   :widths: 20 60 30
   :header-rows: 1

   * - Tutorial
     - Title
     - Colab Link
   * - `Tutorial 1 <https://colab.research.google.com/github/jeshraghian/snntorch/blob/tutorials/examples/tutorial_1_spikegen.ipynb>`_
     - Spike Generation and Visualization with spikegen and spikeplot
     - .. image:: https://colab.research.google.com/assets/colab-badge.svg
        :alt: Open In Colab
        :target: https://colab.research.google.com/github/jeshraghian/snntorch/blob/tutorials/examples/tutorial_1_spikegen.ipynb

   * - Tutorial 2
     - **Under construction:** Neuronal Dynamics with snntorch
     - .. image:: https://colab.research.google.com/assets/colab-badge.svg
        :alt: Open In Colab

   * - Tutorial 3
     - **Under construction:** Deep Learning on static and spiking MNIST
     - .. image:: https://colab.research.google.com/assets/colab-badge.svg
        :alt: Open In Colab


   * - Tutorial 4
     - **Under construction:** Convolutional SNNs 
     - .. image:: https://colab.research.google.com/assets/colab-badge.svg
        :alt: Open In Colab


Future tutorials on spiking neurons and training are scheduled to be completed by April 2021. 